@@ -4,7 +4,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2008 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net
  *
@@ -181,7 +181,7 @@ typedef struct {
 /* Structures for the output format    */
 
 #define SPLT_MAXOLEN 255
-#define SPLT_OUTNUM  10
+#define SPLT_OUTNUM  20
 
 //structure defining the output format
 typedef struct {
@@ -242,6 +242,11 @@ typedef struct {
    * @brief The genre
    */
   unsigned char genre;
+
+  /*
+   * @brief tags version (for mp3) : 1 or 2
+   */
+  int tags_version;
 } splt_tags;
 
 /**
@@ -259,6 +264,11 @@ typedef struct {
    * @brief Name of the new filename issued from the splitpoint
    */
   char *name;
+  /**
+   * @brief Type of the splitpoint
+   * @see splt_type_of_splitpoint
+   */
+  int type;
 } splt_point;
 
 /*****************************/
@@ -287,7 +297,7 @@ typedef struct splt_progres {
   char filename_shorted[512];
   //the current percent of the progress
   float percent_progress;
-  //the number we are currently splitting
+  //the splitpoint that we are currently splitting
   int current_split;
   //the maximum number of splits
   int max_splits;
@@ -330,6 +340,8 @@ typedef struct {
   //1 if the first, 2 if the second
   //the number of splitpoints
   int current_split;
+  //for the user feedback : the current split file number
+  int current_split_file_number;
   //how many splits, this will be modified
   //by check_splitpts_inf_song_length()
   //to really see how many splitpoints we have
@@ -344,7 +356,7 @@ typedef struct {
   //for the progress bar
   splt_progress *p_bar;
   //callback for sending the silence level to the client
-  void (*get_silence_level)(float level, void *user_data);
+  void (*get_silence_level)(long time, float level, void *user_data);
   //user data set by the client for the 'get_silence_level' function
   void *silence_level_client_data;
   //sends a message to the main program to tell him what
@@ -400,8 +412,6 @@ typedef enum {
 typedef enum {
   //output specified by the set_oformat
   SPLT_OUTPUT_FORMAT,
-  //output filename like song_1m_2s_3h__2m_33s_65h.ogg
-  SPLT_OUTPUT_MINS_SECS,
   //the default output
   //it depends of the type of the split
   SPLT_OUTPUT_DEFAULT,
@@ -452,11 +462,13 @@ typedef enum {
   SPLT_NO_TAGS
 } splt_tags_options;
 
+#define SPLT_DEFAULT_OUTPUT "@f_@mm_@ss_@hh__@Mm_@Ss_@Hh"
+
 /**
  * @brief Default output for the cddb and cue.
  * See #mp3splt_set_oformat
  */
-#define SPLT_DEFAULT_OUTPUT "@a - @n - @t"
+#define SPLT_DEFAULT_CDDB_CUE_OUTPUT "@a - @n - @t"
 /**
  * @brief Default output for the syncerror.
  * See #mp3splt_set_oformat
@@ -485,17 +497,24 @@ typedef struct {
   //or that we set manually with the functions
   splt_tags_options tags;
 
+  short xing;
+
   //defines the output filenames
   splt_output_filenames_options output_filenames;
 
   //quiet mode : don't perform CRC check or other interaction with the user
   short quiet_mode;
 
+  //Pretend to split the file, without real split : this option works in
+  //all modes except error mode and dewrap split.
+  short pretend_to_split;
+
   //frame mode (mp3 only). Process all frames, seeking split positions
   //by counting frames and not with bitrate guessing.
   short option_frame_mode;
   //the time of split when split_mode = OPTION_TIME_SPLIT
   float split_time;
+  long overlap_time;
   //this option uses silence detection to auto-adjust splitpoints.
   short option_auto_adjust;
   //input not seekable. enabling this allows you to split mp3 and ogg streams
@@ -504,6 +523,13 @@ typedef struct {
   //if you don't know what this means, set it to FALSE
   short option_input_not_seekable;
 
+  //If this option is SPLT_TRUE, we create directories from the output
+  //file names without parsing for illegal characters the output filenames.
+  //Otherwise, we parse for illegal characters the filenames and replace
+  //them with '_'. The tags are always checked for illegal characters when
+  //set into filenames.
+  short create_dirs_from_filenames;
+
   //PARAMETERS---------------------------------------
   //PARAMETERS for option_auto_adjust and option_silence_mode :
   //the sound level to be considered silence
@@ -538,10 +564,21 @@ typedef struct {
   //- set to -1 to disable
   int remaining_tags_like_x;
 
+  //if to auto increment the tracknumber of the tags
+  int auto_increment_tracknumber_tags;
+
   /**
    * if we enable the silence points log ('mp3splt.log')
    */
   int enable_silence_log;
+
+  /**
+   * If we force the mp3 tags version to 1 or 2;
+   * Set to 0 if force disable;
+   * If disabled, original tags version is set to split files,
+   *  or version 1 if compiled without libid3tag support
+   */
+  int force_tags_version;
 } splt_options;
 
 /**********************************/
@@ -587,7 +624,7 @@ typedef struct {
   void (*set_total_time)(void *state, int *error);
   int (*simple_split)(void *state, const char *output_fname, off_t begin, off_t end);
   void (*split)(void *state, const char *final_fname, double begin_point,
-      double end_point, int *error);
+      double end_point, int *error, int save_end_point);
   int (*scan_silence)(void *state, int *error);
   void (*set_original_tags)(void *state, int *error);
   void (*init)(void *state, int *error);
@@ -955,6 +992,7 @@ typedef struct {
 #define SPLT_ERROR_CRC_FAILED -31
 #define SPLT_ERROR_NO_PLUGIN_FOUND_FOR_FILE -32
 #define SPLT_ERROR_PLUGIN_ERROR -33
+#define SPLT_ERROR_TIME_SPLIT_VALUE_INVALID -34
 
 //output format
 /**
@@ -1017,6 +1055,11 @@ typedef enum {
  * Use #mp3splt_get_int_option to get those options
  */
 typedef enum {
+  /**
+   * Pretend to split the file, without real split : this option works in
+   * all modes except error mode and dewrap split.
+   */
+  SPLT_OPT_PRETEND_TO_SPLIT,
   /*
    * If quiet; we don't do CRC check or human interaction
    */
@@ -1045,6 +1088,22 @@ typedef enum {
    * Default is #SPLT_CURRENT_TAGS
    */
   SPLT_OPT_TAGS,
+  /**
+   * #SPLT_TRUE if we write Xing header (mp3 only)
+   */
+  SPLT_OPT_XING,
+  /**
+   * If this option is SPLT_TRUE, we create directories from the output
+   * file names without parsing for illegal characters the output filenames.
+   *
+   * Otherwise, we parse for illegal characters the filenames and replace
+   * them with '_'. The tags are always checked for illegal characters when
+   * set into filenames.
+   *
+   * Default is #SPLT_FALSE because it's safer to check for illegal
+   * characters.
+   */
+  SPLT_OPT_CREATE_DIRS_FROM_FILENAMES,
   /**
    * The option can take the values from #SPLT_OUTPUT_FILENAMES_OPTIONS
    *
@@ -1114,12 +1173,36 @@ typedef enum {
    * if to set all tags like X one
    */
   SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X,
+  /**
+   * -if we auto increment the tracknumber in the tags
+   */
+  SPLT_OPT_AUTO_INCREMENT_TRACKNUMBER_TAGS,
   /**
    * if we enable the silence points log ('mp3splt.log')
    */
-  SPLT_OPT_ENABLE_SILENCE_LOG
+  SPLT_OPT_ENABLE_SILENCE_LOG,
+  /**
+   * if we force a tags version or not
+   */
+  SPLT_OPT_FORCE_TAGS_VERSION
 } splt_int_options;
 
+//options types : long
+/**
+ * @brief Integer options
+ *
+ * Integer options
+ *
+ * Use #mp3splt_set_long_option to set those options\n
+ * Use #mp3splt_get_long_option to get those options
+ */
+typedef enum {
+  /** 
+   * Time to overlap between the split files
+   */
+  SPLT_OPT_OVERLAP_TIME
+} splt_long_options;
+
 //option types : float
 /**
  * @brief Float options
@@ -1172,6 +1255,18 @@ typedef enum {
   SPLT_OPT_PARAM_MIN_LENGTH
 } splt_float_options;
 
+
+/**
+ * we define a 'skippoint' as a splitpoint that is not taken into
+ * consideration
+ */
+typedef enum {
+  /* a regular splitpoint */
+  SPLT_SPLITPOINT,
+  /* a skippoint */
+  SPLT_SKIPPOINT,
+} splt_type_of_splitpoint;
+
 /**
  * Freedb constants
  */
@@ -1220,7 +1315,7 @@ typedef enum {
 /**
  * @brief Package version
  */
-#define SPLT_PACKAGE_VERSION "0.5.2"
+#define SPLT_PACKAGE_VERSION "0.5.6"
 #endif
 /**
  * @brief Package authors
@@ -1298,7 +1393,7 @@ int mp3splt_set_split_filename_function(splt_state *state,
 int mp3splt_set_progress_function(splt_state *state,
     void (*progress_cb)(splt_progress *p_bar));
 int mp3splt_set_silence_level_function(splt_state *state,
-  void (*get_silence_cb)(float level, void *user_data),
+  void (*get_silence_cb)(long time, float level, void *user_data),
   void *user_data);
 
 /************************************/
@@ -1307,7 +1402,7 @@ int mp3splt_set_silence_level_function(splt_state *state,
 //puts a splitpoint
 //returns possible error
 int mp3splt_append_splitpoint(splt_state *state,
-    long split_value, const char *name);
+    long split_value, const char *name, int type);
 
 //returns a pointer to all the current splitpoints
 const splt_point *mp3splt_get_splitpoints(splt_state *state,
@@ -1344,12 +1439,18 @@ void mp3splt_erase_all_tags(splt_state *state,
 int mp3splt_set_int_option(splt_state *state, int option_name,
     int value);
 
+int mp3splt_set_long_option(splt_state *state, int option_name,
+    long value);
+
 int mp3splt_set_float_option(splt_state *state, int option_name,
     float value);
 
 int mp3splt_get_int_option(splt_state *state, int option_name,
     int *error);
 
+long mp3splt_get_long_option(splt_state *state, int option_name,
+    int *error);
+
 float mp3splt_get_float_option(splt_state *state, int option_name,
     int *error);
 
@@ -1398,15 +1499,17 @@ void mp3splt_write_freedb_file_result(splt_state *state,
     const char *cddb_get_server,
     int port);
 
-//string s is freed, call with strdup for example
 void mp3splt_set_oformat(splt_state *state,
     const char *format_string, int *error);
 
 /************************************/
 /* Other utilities                  */
 
+//counts the number of tracks found with silence detection
 int mp3splt_count_silence_points(splt_state *state, int *error);
 
+int mp3splt_set_silence_points(splt_state *state, int *error);
+
 //returns the version of libmp3splt
 void mp3splt_get_version(char *version);
 
@@ -1419,8 +1522,13 @@ const splt_syncerrors *mp3splt_get_syncerrors(splt_state *state,
     int *error);
 
 //returns the wrapped files found
-const splt_wrap *mp3splt_get_wrap_files(splt_state *state,
-    int *error);
+const splt_wrap *mp3splt_get_wrap_files(splt_state *state, int *error);
+
+int mp3splt_append_plugins_scan_dir(splt_state *state, char *dir);
+
+#ifdef __WIN32__
+char *mp3splt_win32_utf16_to_utf8(const wchar_t *source);
+#endif
 
 #define MP3SPLT_MP3SPLT_H
 
