@@ -73,7 +73,7 @@ int splt_t_get_current_split_file_number(splt_state *state);
 /* types: output format access */
 
 void splt_t_set_oformat(splt_state *state, const char *format_string,
-    int *error);
+    int *error, int ignore_incorrect_format_warning);
 int splt_t_new_oformat(splt_state *state, const char *format_string);
 const char *splt_t_get_oformat(splt_state *state);
 void splt_t_set_oformat_digits_tracks(splt_state *state, int tracks);
@@ -102,7 +102,7 @@ splt_point *splt_t_get_splitpoints(splt_state *state, int *splitpoints_number);
 /********************************/
 /* types: tags access */
 
-void splt_t_set_auto_increment_tracknumber_tag(splt_state *state, int old_current_split, int current_split);
+void splt_t_auto_increment_tracknumber_tag(splt_state *state);
 int splt_t_append_original_tags(splt_state *state);
 void splt_t_get_original_tags(splt_state *state, int *err);
 int splt_t_append_tags(splt_state *state,
@@ -141,9 +141,12 @@ splt_tags splt_t_get_last_tags(splt_state *state);
 
 void splt_t_set_int_option(splt_state *state, int option_name,
     int value);
+void splt_t_set_long_option(splt_state *state, int option_name,
+    long value);
 void splt_t_set_float_option(splt_state *state, int option_name,
     float value);
 int splt_t_get_int_option(splt_state *state, int option_name);
+long splt_t_get_long_option(splt_state *state, int option_name);
 float splt_t_get_float_option(splt_state *state, int option_name);
 //internal :
 void splt_t_set_i_begin_point(splt_state *state, double value);
