@@ -89,6 +89,7 @@ void splt_u_error(int error_type, const char *function,
 float splt_u_silence_position(struct splt_ssplit *temp, float off);
 void splt_u_print_debug(const char *message,double optional, const char *optional2);
 double splt_u_get_double_pos(long split);
+void splt_u_get_mins_secs_hundr(long split_hundr, long *mins, long *secs, long *hundr);
 int splt_u_create_directories(splt_state *state, const char *dir);
 char *splt_u_strerror(splt_state *state, int error_code);
 
@@ -103,6 +104,11 @@ char *splt_u_win32_utf16_to_utf8(const wchar_t *source);
 wchar_t *splt_u_win32_utf8_to_utf16(const char *source);
 #endif
 
+char *splt_u_safe_strdup(char *input, int *error);
+
+void splt_u_print_overlap_time(splt_state *state);
+long splt_u_overlap_time(splt_state *state, int splitpoint_index);
+
 #define MP3SPLT_UTILS_H
 
 #endif
