@@ -53,31 +53,19 @@ static void splt_tag_put_filenames_from_tags(splt_state *state,
   int i = 0;
 
   char *artist0 = NULL;
-  artist0 = strdup(splt_t_get_tags_char_field(state, 0, SPLT_TAGS_ARTIST));
-  if (artist0 == NULL)
-  {
-    *error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-    goto function_end;
-  }
+  char *first_artist = splt_t_get_tags_char_field(state, 0, SPLT_TAGS_ARTIST);
+  artist0 = splt_u_safe_strdup(first_artist, error);
+  if (*error < 0) { goto function_end; }
 
   char *album0 = NULL;
-  album0 = strdup(splt_t_get_tags_char_field(state, 0, SPLT_TAGS_ALBUM));
-  if (album0 == NULL)
-  {
-    *error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-    goto function_end;
-  }
+  char *first_album = splt_t_get_tags_char_field(state, 0, SPLT_TAGS_ALBUM);
+  album0 = splt_u_safe_strdup(first_album, error);
+  if (*error < 0) { goto function_end; }
 
   char *year0 = NULL;
-  if (splt_t_get_tags_char_field(state, 0, SPLT_TAGS_YEAR))
-  {
-    year0 = strdup(splt_t_get_tags_char_field(state, 0, SPLT_TAGS_YEAR));
-    if (year0 == NULL)
-    {
-      *error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-      goto function_end;
-    }
-  }
+  char *first_year = splt_t_get_tags_char_field(state, 0, SPLT_TAGS_YEAR);
+  year0 = splt_u_safe_strdup(first_year, error);
+  if (*error < 0) { goto function_end; }
 
   char *performer = NULL;
   unsigned char genre0 = splt_t_get_tags_uchar_field(state, 0, SPLT_TAGS_GENRE);
@@ -89,8 +77,8 @@ static void splt_tag_put_filenames_from_tags(splt_state *state,
   if (output_filenames == SPLT_OUTPUT_DEFAULT)
   {
     //we put the default output if we have the default output
-    int err = splt_t_new_oformat(state, SPLT_DEFAULT_OUTPUT);
-    if (err < 0) { *error = err; goto function_end; }
+    splt_t_set_oformat(state, SPLT_DEFAULT_CDDB_CUE_OUTPUT, error, SPLT_TRUE);
+    if (*error < 0) { goto function_end; }
 
     //we put the real performer in the artist
     for (i = 0; i < tracks;i++)
@@ -164,13 +152,14 @@ static void splt_tag_put_filenames_from_tags(splt_state *state,
   {
     int err_format = SPLT_OK;
 
-    if (splt_t_get_oformat(state) != NULL)
+    const char *format = splt_t_get_oformat(state);
+    if (format != NULL)
     {
       //we put the outputted filename
-      char *old_format = strdup(splt_t_get_oformat(state));
+      char *old_format = strdup(format);
       if (old_format != NULL)
       {
-        splt_t_set_oformat(state, old_format,&err_format);
+        splt_t_set_oformat(state, old_format,&err_format, SPLT_TRUE);
         free(old_format);
         old_format = NULL;
       }
@@ -393,6 +382,16 @@ int splt_cue_put_splitpoints(const char *file, splt_state *state, int *error)
       //we read the file line by line
       while (fgets(line, 2048, file_input)!=NULL)
       {
+        //if windows file with '\r', then pretend is a unix file
+        if (strlen(line) > 1)
+        {
+          if (line[strlen(line)-2] == '\r')
+          {
+            line[strlen(line)-2] = '\n';
+            line[strlen(line)-1] = '\0';
+          }
+        }
+
         type = SPLT_CUE_NOTHING;
 
         //we read strings from file TRACK,TITLE,AUDIO,PERFORMER,INDEX
@@ -597,7 +596,7 @@ function_end:
 //returns number of tracks
 //see freedb file format documentation on freedb.org
 //-file must not be NULL
-int splt_cddb_put_splitpoints (const char *file, splt_state *state, int *error)
+int splt_cddb_put_splitpoints(const char *file, splt_state *state, int *error)
 {
   //clear previous splitpoints
   splt_t_free_splitpoints_tags(state);
