@@ -4,7 +4,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2008 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net
  *
@@ -37,21 +37,27 @@
 #include "splt.h"
 #include "plugins.h"
 
+#ifdef __WIN32__
+#include <direct.h>
+#endif
+
 //mingw does not provide BSD functions 'scandir' and 'alphasort'
 #ifdef __WIN32__
 
 //-returns -1 for not enough memory, -2 for other errors
 //-a positive (or 0) number if success
-int scandir(const char *dir, struct dirent ***namelist,
-		int(*filter)(const struct dirent *),
-		int(*compar)(const struct dirent **, const struct dirent **))
+int scandir(const char *dir, struct _wdirent ***namelist,
+		int(*filter)(const struct _wdirent *),
+		int(*compar)(const struct _wdirent **, const struct _wdirent **))
 {
-  struct dirent **files = NULL;
-  struct dirent *file = NULL;
-  DIR *directory = NULL;
+  struct _wdirent **files = NULL;
+  struct _wdirent *file = NULL;
+  _WDIR *directory = NULL;
   int number_of_files = 0;
 
-  directory = opendir(dir);
+  wchar_t *wdir = splt_u_win32_utf8_to_utf16(dir);
+  directory = _wopendir(wdir);
+  if (wdir) { free(wdir); wdir = NULL; }
   if (directory == NULL)
   {
     return -2;
@@ -60,7 +66,7 @@ int scandir(const char *dir, struct dirent ***namelist,
   int free_memory = 0;
   int we_have_error = 0;
 
-  while (file = readdir(directory))
+  while ((file = _wreaddir(directory)))
   {
     if ((filter == NULL) || (filter(file)))
     {
@@ -79,7 +85,7 @@ int scandir(const char *dir, struct dirent ***namelist,
         break;
       }
 
-      files[number_of_files] = malloc(sizeof(DIR));
+      files[number_of_files] = malloc(sizeof(struct _wdirent));
       if (files[number_of_files] == NULL)
       {
         free_memory = 1;
@@ -117,7 +123,7 @@ int scandir(const char *dir, struct dirent ***namelist,
     files = NULL;
   }
 
-  if (closedir(directory) == -1)
+  if (_wclosedir(directory) == -1)
   {
     return -2;
   }
@@ -133,104 +139,165 @@ int scandir(const char *dir, struct dirent ***namelist,
   return number_of_files;
 }
 
-int alphasort(const struct dirent **a, const struct dirent **b)
+int alphasort(const struct _wdirent **a, const struct _wdirent **b)
 {
-  return strcoll((*a)->d_name, (*b)->d_name);
+  char *name_a = splt_u_win32_utf16_to_utf8((*a)->d_name);
+  char *name_b = splt_u_win32_utf16_to_utf8((*b)->d_name);
+
+  int ret = strcoll(name_a, name_b);
+
+  if (name_a)
+  {
+    free(name_a);
+    name_a = NULL;
+  }
+
+  if (name_b)
+  {
+    free(name_b);
+    name_b = NULL;
+  }
+
+  return ret;
 }
 
 #endif
 
-//sets the plugin scan directories
-static int splt_p_set_default_plugins_scan_dirs(splt_state *state)
+int splt_p_append_plugin_scan_dir(splt_state *state, char *dir)
 {
   splt_plugins *pl = state->plug;
-  pl->number_of_dirs_to_scan = 3;
-  //allocate memory
-  pl->plugins_scan_dirs = malloc(sizeof(char *) * pl->number_of_dirs_to_scan);
+
+  //allocate memory for another char * pointer
+  if (pl->plugins_scan_dirs == NULL)
+  {
+    //allocate memory
+    pl->plugins_scan_dirs = malloc(sizeof(char *));
+  }
+  else
+  {
+    pl->plugins_scan_dirs = realloc(pl->plugins_scan_dirs,
+        sizeof(char *) * (pl->number_of_dirs_to_scan + 1));
+  }
   if (pl->plugins_scan_dirs == NULL)
   {
     return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
   }
-  memset(pl->plugins_scan_dirs,0,sizeof(char *) * pl->number_of_dirs_to_scan);
+  pl->plugins_scan_dirs[pl->number_of_dirs_to_scan] = NULL;
 
-  //temporary variable that we use to set the default directories
-  char temp[2048] = { '\0' };
-
-  //we put the default plugin directory
-  snprintf(temp,2048,"%s",SPLT_PLUGINS_DIR);
-  pl->plugins_scan_dirs[0] = malloc(sizeof(char) * (strlen(temp)+1));
-  if (pl->plugins_scan_dirs[0] == NULL)
+  //allocate memory for this directory name
+  pl->plugins_scan_dirs[pl->number_of_dirs_to_scan] = malloc(sizeof(char) * (strlen(dir)+1));
+  if (pl->plugins_scan_dirs[pl->number_of_dirs_to_scan] == NULL)
   {
     return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
   }
-  snprintf(pl->plugins_scan_dirs[0],strlen(temp)+1,"%s",temp);
 
-  //we put the home libmp3splt home directory
-  snprintf(temp,2048,"%s%c%s",getenv("HOME"),SPLT_DIRCHAR,".libmp3splt");
-  pl->plugins_scan_dirs[1] = malloc(sizeof(char) * (strlen(temp)+1));
-  if (pl->plugins_scan_dirs[1] == NULL)
-  {
-    return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-  }
-  snprintf(pl->plugins_scan_dirs[1],strlen(temp)+1,"%s",temp);
+  snprintf(pl->plugins_scan_dirs[pl->number_of_dirs_to_scan],strlen(dir)+1,"%s",dir);
 
-  //we put the current directory
-  memset(temp,'\0',2048);
-  snprintf(temp,2048,".%c",SPLT_DIRCHAR);
-  pl->plugins_scan_dirs[2] = malloc(sizeof(char) * (strlen(temp)+1));
-  if (pl->plugins_scan_dirs[2] == NULL)
-  {
-    return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-  }
-  snprintf(pl->plugins_scan_dirs[2],strlen(temp)+1,"%s",temp);
+  pl->number_of_dirs_to_scan++;
 
   return SPLT_OK;
 }
 
-//function to filter the plugin files
-static int splt_p_filter_plugin_files(const struct dirent *de)
+//sets the plugin scan directories
+int splt_p_set_default_plugins_scan_dirs(splt_state *state)
 {
-  int file_length = strlen(de->d_name);
+  int err = SPLT_OK;
+
+  //temporary variable that we use to set the default directories
+  char temp[2048] = { '\0' };
+
+#ifndef __WIN32__
+  //we put the default plugin directory
+  snprintf(temp,2048,"%s",SPLT_PLUGINS_DIR);
+  if ((err = splt_p_append_plugin_scan_dir(state, temp)) != SPLT_OK) { return err; }
+#endif
+
+  //we put the home libmp3splt home directory
+  snprintf(temp,2048,"%s%c%s",getenv("HOME"),SPLT_DIRCHAR,".libmp3splt");
+  if ((err = splt_p_append_plugin_scan_dir(state, temp)) != SPLT_OK) { return err; }
+
+  //we put the current directory
+  memset(temp,'\0',2048);
+  snprintf(temp,2048,".%c",SPLT_DIRCHAR);
+  if ((err = splt_p_append_plugin_scan_dir(state, temp)) != SPLT_OK) { return err; }
+
+  return err;
+}
+
+//function to filter the plugin files
+#ifdef __WIN32__
+static int splt_p_filter_plugin_files(const struct _wdirent *de)
+#else
+static int splt_p_filter_plugin_files(const struct dirent *de)
+#endif
+{
+#ifdef __WIN32__
+  char *file = splt_u_win32_utf16_to_utf8(de->d_name);
+#else
   char *file = (char *) de->d_name;
+#endif
   char *p_end = NULL;
   char *p_start = NULL;
-  if (strlen(file) >= 8)
+  if (file)
   {
-    //if the name starts with splt_and contains .so or .sl or .dll or .dylib
-    if (strncmp(file,"libsplt_",8) == 0)
+    if (strlen(file) >= 8)
     {
-      splt_u_print_debug("Looking at the file ",0, file);
-      //find the last '.' character
-      p_end = strrchr(file,'.');
-      p_start = strchr(file,'.');
-      //we only look at files containing only one dot
-      if ((p_end != NULL) && (p_start == p_end))
+      //if the name starts with splt_and contains .so or .sl or .dll or .dylib
+      if (strncmp(file,"libsplt_",8) == 0)
       {
-        if ((strcmp(p_end,".so") == 0) ||
-            (strcmp(p_end,".sl") == 0) ||
-            (strcmp(p_end,".dll") == 0) ||
-            (strcmp(p_end,".dylib") == 0))
+        splt_u_print_debug("Looking at the file ",0, file);
+        //find the last '.' character
+        p_end = strrchr(file,'.');
+        p_start = strchr(file,'.');
+        //we only look at files containing only one dot
+        if ((p_end != NULL) && (p_start == p_end))
         {
-          return 1;
+          if ((strcmp(p_end,".so") == 0) ||
+              (strcmp(p_end,".sl") == 0) ||
+              (strcmp(p_end,".dll") == 0) ||
+              (strcmp(p_end,".dylib") == 0))
+          {
+#ifdef __WIN32__
+            if (file)
+            {
+              free(file);
+              file = NULL;
+            }
+#endif
+            return 1;
+          }
         }
       }
     }
   }
 
+#ifdef __WIN32__
+  if (file)
+  {
+    free(file);
+    file = NULL;
+  }
+#endif
+
   return 0;
 }
 
 //scans the directory *directory for plugins
 //-directory must not be NULL
-static int splt_p_scan_dir_for_plugins(splt_plugins *pl, const char *directory)
+static int splt_p_scan_dir_for_plugins(splt_state *state, splt_plugins *pl, const char *directory)
 {
   int return_value = SPLT_OK;
 
+#ifdef __WIN32__
+  struct _wdirent **files = NULL;
+#else
   struct dirent **files = NULL;
+#endif
+
   int number_of_files = 0;
   //scan the directory
-  number_of_files = scandir(directory, &files,
-      splt_p_filter_plugin_files, alphasort);
+  number_of_files = scandir(directory, &files, splt_p_filter_plugin_files,
+      alphasort);
   int directory_len = strlen(directory);
   int new_number_of_files = number_of_files;
 
@@ -240,42 +307,105 @@ static int splt_p_scan_dir_for_plugins(splt_plugins *pl, const char *directory)
   }
   else if (new_number_of_files >= 0)
   {
+    char *fname = NULL;
+
     //for all the filtered found plugins,
     //copy their name
     while (new_number_of_files--)
     {
-      char *fname = files[new_number_of_files]->d_name;
+#ifdef __WIN32__
+      fname = splt_u_win32_utf16_to_utf8(files[new_number_of_files]->d_name);
+#else
+      fname = files[new_number_of_files]->d_name;
+#endif
       int fname_len = strlen(fname);
 
-      int alloc_err = splt_t_alloc_init_new_plugin(pl);
-      if (alloc_err < 0)
-      {
-        return_value = alloc_err;
-        goto end;
-      }
-    
-      pl->data[pl->number_of_plugins_found].func = malloc(sizeof(splt_plugin_func));
-      if (pl->data[pl->number_of_plugins_found].func == NULL)
+      //get the full directory + filename
+      int dir_and_fname_len = fname_len + directory_len + 3;
+      char *dir_and_fname = malloc(sizeof(char) * dir_and_fname_len);
+      if (dir_and_fname == NULL)
       {
         return_value = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
         goto end;
       }
-      memset(pl->data[pl->number_of_plugins_found].func,0,sizeof(splt_plugin_func));
-      pl->data[pl->number_of_plugins_found].plugin_filename = malloc(sizeof(char) *
-          (fname_len+directory_len+3));
-      if (pl->data[pl->number_of_plugins_found].plugin_filename == NULL)
+      snprintf(dir_and_fname, dir_and_fname_len - 1, "%s%c%s",directory,SPLT_DIRCHAR,fname);
+
+      //check if we already have a plugin with the same file
+      int we_already_have_this_plugin_file = SPLT_FALSE;
+      int i = 0;
+      int err = SPLT_OK;
+      for (i = 0;i < pl->number_of_plugins_found;i++)
       {
-        return_value = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-        goto end;
+        if (splt_check_is_the_same_file(state, dir_and_fname, pl->data[i].plugin_filename, &err))
+        {
+          we_already_have_this_plugin_file = SPLT_TRUE;
+          break;
+        }
+
+        if (err != SPLT_OK)
+        {
+          return_value = err;
+          goto end;
+        }
       }
-      //set the plugin name and the directory
-      snprintf(pl->data[pl->number_of_plugins_found].plugin_filename,
-          fname_len+directory_len+2,"%s%c%s",directory,SPLT_DIRCHAR,fname);
-      pl->number_of_plugins_found++;
+
+      //if we don't have a plugin from the same file, add this new plugin
+      if (! we_already_have_this_plugin_file)
+      {
+        int alloc_err = splt_t_alloc_init_new_plugin(pl);
+        if (alloc_err < 0)
+        {
+          return_value = alloc_err;
+          goto end;
+        }
+
+        pl->data[pl->number_of_plugins_found].func = malloc(sizeof(splt_plugin_func));
+        if (pl->data[pl->number_of_plugins_found].func == NULL)
+        {
+          return_value = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+          goto end;
+        }
+        memset(pl->data[pl->number_of_plugins_found].func,0,sizeof(splt_plugin_func));
+        pl->data[pl->number_of_plugins_found].plugin_filename = malloc(sizeof(char) *
+            dir_and_fname_len);
+        if (pl->data[pl->number_of_plugins_found].plugin_filename == NULL)
+        {
+          return_value = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+          goto end;
+        }
+        //set the plugin name and the directory
+        snprintf(pl->data[pl->number_of_plugins_found].plugin_filename,
+            dir_and_fname_len - 1,"%s%c%s",directory,SPLT_DIRCHAR,fname);
+
+        pl->number_of_plugins_found++;
+      }
+
+      //free some memory
+      if (dir_and_fname)
+      {
+        free(dir_and_fname);
+        dir_and_fname = NULL;
+      }
+
+#ifdef __WIN32__
+      if (fname)
+      {
+        free(fname);
+        fname = NULL;
+      }
+#endif
     }
 
 end:
+#ifdef __WIN32__
+    if (fname)
+    {
+      free(fname);
+      fname = NULL;
+    }
+#endif
     ;
+
     if (files)
     {
       //free memory
@@ -304,17 +434,6 @@ static int splt_p_find_plugins(splt_state *state)
 
   splt_plugins *pl = state->plug;
 
-  //if we don't have any directory set for scanning
-  if (pl->plugins_scan_dirs == NULL)
-  {
-    //set the default directories
-    return_value = splt_p_set_default_plugins_scan_dirs(state);
-    if (return_value != SPLT_OK)
-    {
-      return return_value;
-    }
-  }
-
   //for each scan directory, look for the files starting with 'splt' and
   //ending with '.so' on unix-like and '.dll' on windows
   int i = 0;
@@ -334,7 +453,7 @@ static int splt_p_find_plugins(splt_state *state)
             strncmp(pl->plugins_scan_dirs[i], current_dir,2) == 0) ||
           splt_u_check_if_directory(pl->plugins_scan_dirs[i]))
       {
-        return_value = splt_p_scan_dir_for_plugins(pl, pl->plugins_scan_dirs[i]);
+        return_value = splt_p_scan_dir_for_plugins(state, pl, pl->plugins_scan_dirs[i]);
         if (return_value != SPLT_OK)
         {
           return return_value;
@@ -346,23 +465,91 @@ static int splt_p_find_plugins(splt_state *state)
   return return_value;
 }
 
+int splt_p_move_replace_plugin_data(splt_state *state, int old, int new)
+{
+  splt_plugins *pl = state->plug;
+
+  splt_t_free_plugin_data(pl->data[new]);
+
+  pl->data[new].func = malloc(sizeof(splt_plugin_func));
+  if (pl->data[new].func == NULL)
+  {
+    return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+  }
+  memcpy(pl->data[new].func, pl->data[old].func, sizeof(pl->data[old].func));
+
+  int plugin_fname_len = strlen(pl->data[old].plugin_filename) + 1;
+  pl->data[new].plugin_filename = malloc(sizeof(char) * plugin_fname_len);
+  if (pl->data[new].plugin_filename == NULL)
+  {
+    return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+  }
+  snprintf(pl->data[new].plugin_filename, plugin_fname_len, "%s",
+      pl->data[old].plugin_filename);
+
+  splt_t_free_plugin_data(pl->data[old]);
+
+  return SPLT_OK;
+}
+
+//shifts all the elements to the left, starting at element index+1
+static int splt_p_shift_left_plugins_data(splt_state *state, int index)
+{
+  int i = 0;
+  splt_plugins *pl = state->plug;
+
+  for (i = index+1;i < pl->number_of_plugins_found;i++)
+  {
+    int err = splt_p_move_replace_plugin_data(state, i, i - 1);
+    if (err != SPLT_OK)
+    {
+      return err;
+    }
+  }
+
+  return SPLT_OK;
+}
+
 //function that gets information of each plugin
 static int splt_p_open_get_plugins_data(splt_state *state)
 {
   splt_plugins *pl = state->plug;
+
+  int *plugin_index_to_remove = NULL;
+  int number_of_plugins_to_remove = 0;
+
   int error = SPLT_OK;
 
   int i = 0;
   for (i = 0;i < pl->number_of_plugins_found;i++)
   {
+    splt_u_print_debug("\nTrying to open the plugin ...",0,pl->data[i].plugin_filename);
+
+    //ltdl currently does not supports windows unicode path/filename
     pl->data[i].plugin_handle = lt_dlopen(pl->data[i].plugin_filename);
     //error
     if (! pl->data[i].plugin_handle)
     {
       splt_u_print_debug("Error loading the plugin",0,pl->data[i].plugin_filename);
+      splt_u_print_debug(" - error message from libltdl : ",0,lt_dlerror());
+
+      //keep the index of this failed plugin in order to remove it
+      //afterwards
+      if (! plugin_index_to_remove)
+      {
+        plugin_index_to_remove = malloc(sizeof(int));
+      }
+      else
+      {
+        plugin_index_to_remove = realloc(plugin_index_to_remove, sizeof(int) * (number_of_plugins_to_remove + 1));
+      }
+      plugin_index_to_remove[number_of_plugins_to_remove] = i;
+      number_of_plugins_to_remove++;
     }
     else
     {
+      splt_u_print_debug(" - success !",0,NULL);
+
       //get pointers to functions from the plugins
       //-this function must only be called once and here 
       *(void **) (&pl->data[i].func->check_plugin_is_for_file) =
@@ -388,13 +575,75 @@ static int splt_p_open_get_plugins_data(splt_state *state)
       if (pl->data[i].func->set_plugin_info != NULL)
       {
         pl->data[i].func->set_plugin_info(&pl->data[i].info,&error);
+        /*splt_t_set_current_plugin(state, i);
+        const char *p_name = splt_p_get_name(state, &error);
+        fprintf(stdout," Plugin NAME = _%s_\n",p_name);
+        fflush(stdout);*/
       }
       else
       {
       }
+
+      //look if we already have a plugin with the same name
+      int j = 0;
+      splt_t_set_current_plugin(state, i);
+      const char *current_plugin_name = splt_p_get_name(state, &error);
+      for (j = 0;j < i;j++)
+      {
+        if (pl->data[j].plugin_handle)
+        {
+          splt_t_set_current_plugin(state, j);
+          const char *plugin_name = splt_p_get_name(state, &error);
+          //if we do have one with the same name,
+          if (strcmp(plugin_name,current_plugin_name) == 0)
+          {
+            //keep its index to remove it afterwards
+            if (! plugin_index_to_remove)
+            {
+              plugin_index_to_remove = malloc(sizeof(int));
+            }
+            else
+            {
+              plugin_index_to_remove = realloc(plugin_index_to_remove, sizeof(int) * (number_of_plugins_to_remove + 1));
+            }
+            plugin_index_to_remove[number_of_plugins_to_remove] = i;
+            number_of_plugins_to_remove++;
+          }
+        }
+      }
     }
   }
 
+  //remove the plugins that failed to open
+  //-some plugins fail to open twice (on Windows for example)
+  int left_shift = 0;
+  //we shift to the left the plugin data in order to replace the bad
+  //plugins with the others
+  for (i = 0;i < number_of_plugins_to_remove;i++) 
+  {
+    int index_to_remove = plugin_index_to_remove[i] - left_shift;
+
+    splt_u_print_debug("Removing the plugin ",0, pl->data[index_to_remove].plugin_filename);
+
+    error = splt_p_shift_left_plugins_data(state, index_to_remove);
+    if (error != SPLT_OK)
+    {
+      goto end;
+    }
+
+    pl->number_of_plugins_found--;
+    left_shift++;
+  }
+
+end:
+  //free the plugin index to remove
+  if (plugin_index_to_remove)
+  {
+    free(plugin_index_to_remove);
+    plugin_index_to_remove = NULL;
+  }
+  number_of_plugins_to_remove = 0;
+
   return error;
 }
 
@@ -405,10 +654,8 @@ int splt_p_find_get_plugins_data(splt_state *state)
 {
   int return_value = SPLT_OK;
 
-  //free old plugins
-  splt_t_free_plugins(state);
-
   splt_u_print_debug("\nSearching for plugins ...",0,NULL);
+
   //find the plugins
   return_value = splt_p_find_plugins(state);
 
@@ -570,7 +817,7 @@ void splt_p_dewrap(splt_state *state, int listonly, const char *dir, int *error)
 }
 
 void splt_p_split(splt_state *state, const char *final_fname, double begin_point,
-    double end_point, int *error)
+    double end_point, int *error, int save_end_point)
 {
   splt_plugins *pl = state->plug;
   int current_plugin = splt_t_get_current_plugin(state);
@@ -584,7 +831,7 @@ void splt_p_split(splt_state *state, const char *final_fname, double begin_point
     if (pl->data[current_plugin].func->split != NULL)
     {
       pl->data[current_plugin].func->split(state, final_fname,
-          begin_point, end_point, error);
+          begin_point, end_point, error, save_end_point);
     }
     else
     {
@@ -647,7 +894,7 @@ int splt_p_simple_split(splt_state *state, const char *output_fname, off_t begin
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     error = SPLT_ERROR_NO_PLUGIN_FOUND;
-    return;
+    return error;
   }
   else
   {
