@@ -49,18 +49,21 @@ static void splt_s_real_split(splt_state *state, int *error, int save_end_point)
 
   if (*error >= 0)
   {
-    splt_p_split(state, final_fname, splt_beg, splt_end, error, save_end_point);
-
-    //if no error
-    if (*error >= 0)
+    if (!splt_t_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
     {
-      //automatically set progress callback to 100%
-      splt_t_update_progress(state,1.0,1.0,1,1,1);
+      splt_p_split(state, final_fname, splt_beg, splt_end, error, save_end_point);
 
-      //we put the split file
-      int err = SPLT_OK;
-      err = splt_t_put_split_file(state, final_fname);
-      if (err < 0) { *error = err; }
+      //if no error
+      if (*error >= 0)
+      {
+        //automatically set progress callback to 100%
+        splt_t_update_progress(state,1.0,1.0,1,1,1);
+
+        //we put the split file
+        int err = SPLT_OK;
+        err = splt_t_put_split_file(state, final_fname);
+        if (err < 0) { *error = err; }
+      }
     }
   }
 
@@ -73,9 +76,6 @@ static void splt_s_real_split(splt_state *state, int *error, int save_end_point)
 }
 
 //simple split with only 2 splitpoints
-//i is the current splitpoint
-//(used to get the filename)
-//error in error parameter
 static void splt_s_split(splt_state *state, int first_splitpoint,
     int second_splitpoint, int *error)
 {
@@ -90,19 +90,14 @@ static void splt_s_split(splt_state *state, int first_splitpoint,
   split_begin = splt_t_get_splitpoint_value(state, first_splitpoint, &get_error);
   split_end = splt_t_get_splitpoint_value(state, second_splitpoint, &get_error);
   int save_end_point = SPLT_TRUE;
-  if (splt_t_get_splitpoint_type(state, second_splitpoint, &get_error) == SPLT_SKIPPOINT)
+  if (splt_t_get_splitpoint_type(state, second_splitpoint, &get_error) == SPLT_SKIPPOINT ||
+      splt_t_get_long_option(state, SPLT_OPT_OVERLAP_TIME) > 0)
   {
     save_end_point = SPLT_FALSE;
   }
 
   if (get_error == SPLT_OK)
   {
-    //if we put mins and secs
-    if (splt_t_get_int_option(state, SPLT_OPT_OUTPUT_FILENAMES) == SPLT_OUTPUT_MINS_SECS)
-    {
-      splt_u_set_complete_mins_secs_filename(state, error);
-    }
-
     //if no error
     if (*error >= 0)
     {
@@ -131,6 +126,11 @@ static void splt_s_split(splt_state *state, int first_splitpoint,
         //we do the real split
         splt_s_real_split(state, error, save_end_point);
       }
+      else
+      {
+        splt_t_set_error_data_from_splitpoint(state, split_begin);
+        *error = SPLT_ERROR_EQUAL_SPLITPOINTS;
+      }
     }
   }
   else
@@ -155,6 +155,8 @@ void splt_s_multiple_split(splt_state *state, int *error)
     splt_t_put_message_to_client(state, " info: starting normal split\n");
   }
 
+  splt_u_print_overlap_time(state);
+
   int get_error = SPLT_OK;
 
   //for every 2 splitpoints, split
@@ -164,62 +166,40 @@ void splt_s_multiple_split(splt_state *state, int *error)
     //we put the current file to split
     splt_t_set_current_split(state, i);
 
+    splt_t_auto_increment_tracknumber_tag(state);
+
     //if we don't cancel the split
     if (!splt_t_split_is_canceled(state))
     {
       get_error = SPLT_OK;
 
-      //if we have to put the original tags
+      long saved_end_point = splt_t_get_splitpoint_value(state, i+1, &get_error);
+      splt_u_overlap_time(state, i+1);
+
       if (splt_t_get_int_option(state, SPLT_OPT_TAGS) == SPLT_TAGS_ORIGINAL_FILE)
       {
-        int err = SPLT_OK;
-
-        //we put the original tags to the current split
         err = splt_t_append_original_tags(state);
         if (err < 0) { *error = err; return; }
       }
 
-      //we look what option we have for the output filenames
-      int output_filenames = splt_t_get_int_option(state, SPLT_OPT_OUTPUT_FILENAMES);
-      if (output_filenames == SPLT_OUTPUT_FORMAT)
+      err = splt_u_put_output_format_filename(state);
+      if (err < 0) { *error = err; return; }
+
+      int first_splitpoint_type = splt_t_get_splitpoint_type(state, i, &get_error);
+      if (first_splitpoint_type == SPLT_SKIPPOINT)
       {
-        err = splt_u_put_output_format_filename(state);
-        if (err < 0) { *error = err; return; }
+        i++;
+        continue;
       }
 
-      char *temp_name = splt_t_get_splitpoint_name(state, i, &get_error);
-      if (get_error == SPLT_OK)
+      splt_s_split(state, i, i+1, error);
+
+      splt_t_set_splitpoint_value(state, i+1,saved_end_point);
+
+      //get out if error
+      if ((*error < 0) || (*error == SPLT_OK_SPLIT_EOF))
       {
-        //if we have no filename, we put option mins secs
-        if ((temp_name == NULL) || (temp_name[0] == '\0'))
-        {
-          splt_t_set_int_option(state, SPLT_OPT_OUTPUT_FILENAMES, SPLT_OUTPUT_MINS_SECS);
-        }
-
-        //we split only if the type of the first splitpoint is SPLT_SPLITPOINT
-        int first_splitpoint_type = splt_t_get_splitpoint_type(state, i, &get_error);
-        if (first_splitpoint_type == SPLT_SKIPPOINT)
-        {
-          i++;
-          continue;
-        }
-
-        if (!splt_t_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
-        {
-          splt_s_split(state, i, i+1, error);
-        }
-
-        //get out if error
-        if ((*error < 0) ||
-            (*error == SPLT_OK_SPLIT_EOF))
-        {
-          break;
-        }
-      }
-      else
-      {
-        *error = get_error;
-        return;
+        break;
       }
     }
     else
@@ -231,6 +211,18 @@ void splt_s_multiple_split(splt_state *state, int *error)
   }
 }
 
+void splt_s_normal_split(splt_state *state, int *error)
+{
+  int output_filenames = splt_t_get_int_option(state,SPLT_OPT_OUTPUT_FILENAMES);
+  if (output_filenames == SPLT_OUTPUT_DEFAULT)
+  {
+    splt_t_set_oformat(state, SPLT_DEFAULT_OUTPUT, error, SPLT_TRUE);
+    if (*error < 0) { return; }
+  }
+
+  splt_s_multiple_split(state, error);
+}
+
 //the sync error mode
 void splt_s_error_split(splt_state *state, int *error)
 {
@@ -247,14 +239,17 @@ void splt_s_error_split(splt_state *state, int *error)
   int err = SPLT_OK;
 
   //if no error
-  if (*error >= 0 && err >= 0)
+  if (*error >= 0)
   {
     //we put the number of sync errors
     splt_t_set_splitnumber(state, state->serrors->serrors_points_num - 1);
 
+    splt_t_set_oformat_digits(state);
+
     if (splt_t_get_int_option(state,SPLT_OPT_OUTPUT_FILENAMES) == SPLT_OUTPUT_DEFAULT)
     {
-      splt_t_set_oformat(state, SPLT_DEFAULT_SYNCERROR_OUTPUT,&err);
+      splt_t_set_oformat(state, SPLT_DEFAULT_SYNCERROR_OUTPUT, &err, SPLT_TRUE);
+      if (err < 0) { *error = err; goto bloc_end; }
     }
 
     //we split all sync errors
@@ -267,6 +262,8 @@ void splt_s_error_split(splt_state *state, int *error)
         //we put the current file to split
         splt_t_set_current_split(state, i);
 
+        splt_t_auto_increment_tracknumber_tag(state);
+
         //we append a splitpoint
         int err = splt_t_append_splitpoint(state, 0, "", SPLT_SPLITPOINT);
         if (err < 0) { *error = err; goto bloc_end; }
@@ -357,30 +354,51 @@ void splt_s_time_split(splt_state *state, int *error)
   splt_u_print_debug("Starting time split...",0,NULL);
   splt_t_put_message_to_client(state, " info: starting time mode split\n");
 
+  splt_u_print_overlap_time(state);
+
   char *final_fname = NULL;
   //if the state has an error
   int j=0,tracks=1;
   //the begin split
   double begin = 0.f;
   double end = (double) splt_t_get_float_option(state, SPLT_OPT_SPLIT_TIME);
+  if (end == 0.0)
+  {
+    *error = SPLT_ERROR_TIME_SPLIT_VALUE_INVALID;
+    return;
+  }
 
   //if no state error
-  if (state->options.split_time >= 0)
+  if (end >= 0)
   {
     int err = SPLT_OK;
 
-    int temp_int = 
-      (int)floor(((splt_t_get_total_time(state)/100.0) /
-            (state->options.split_time))+1) + 1;
+    int temp_int = (int)floor(((splt_t_get_total_time(state)/100.0) /
+          (state->options.split_time))+1) + 1;
     splt_t_set_splitnumber(state,temp_int);
 
     splt_t_set_oformat_digits(state);
 
+    //if we have the default output
+    int output_filenames = splt_t_get_int_option(state, SPLT_OPT_OUTPUT_FILENAMES);
+    if (output_filenames == SPLT_OUTPUT_DEFAULT)
+    {
+      splt_t_set_oformat(state, SPLT_DEFAULT_OUTPUT, &err, SPLT_TRUE);
+      if (err < 0) { *error = err; return; }
+    }
+
     //we append a splitpoint
     err = splt_t_append_splitpoint(state, 0, "", SPLT_SPLITPOINT);
-
     if (err >= 0)
-    {
+    { 
+      int save_end_point = SPLT_TRUE;
+      if (splt_t_get_long_option(state, SPLT_OPT_OVERLAP_TIME) > 0)
+      {
+        save_end_point = SPLT_FALSE;
+      }
+
+      int last_file = SPLT_FALSE;
+
       //while we have tracks
       do {
         //if we don't cancel the split
@@ -401,36 +419,27 @@ void splt_s_time_split(splt_state *state, int *error)
           //we set the current split
           splt_t_set_current_split(state, tracks-1);
 
+          splt_t_auto_increment_tracknumber_tag(state);
+
           int current_split = splt_t_get_current_split(state);
-          int output_filenames = 
-            splt_t_get_int_option(state, SPLT_OPT_OUTPUT_FILENAMES);
-          //if we have the default output or the mins_secs
-          if ((output_filenames == SPLT_OUTPUT_DEFAULT)
-              || (output_filenames == SPLT_OUTPUT_MINS_SECS))
+
+          //we put the splitpoints values in the state
+          splt_t_set_splitpoint_value(state, current_split,(long)(begin*100));
+          long end_splitpoint = end*100;
+          if (end_splitpoint > splt_t_get_total_time(state))
           {
-            //we put the splitpoints values in the state
-            splt_t_set_splitpoint_value(state, current_split,(long)(begin*100));
-            long end_splitpoint = end*100;
-            if (end_splitpoint > splt_t_get_total_time(state))
-            {
-              end_splitpoint = splt_t_get_total_time(state);
-            }
-            splt_t_set_splitpoint_value(state, current_split+1,end_splitpoint);
-            //we put the filename with mins_secs
-            splt_u_set_complete_mins_secs_filename(state, &err);
-            if (err < 0) { *error = err; break; }
-          }
-          else
-          {
-            //if we have the output format
-            if (output_filenames == SPLT_OUTPUT_FORMAT)
-            {
-              //if we have the output option
-              //we put the output filename
-              err = splt_u_put_output_format_filename(state);
-              if (err < 0) { *error = err; break; }
-            }
+            end_splitpoint = splt_t_get_total_time(state);
+            //avoid worst scenarios where floor & SPLT_OK_SPLIT_EOF do not
+            //work
+            last_file = SPLT_TRUE;
           }
+          splt_t_set_splitpoint_value(state, current_split+1,end_splitpoint);
+
+          double overlapped_end =
+            (double)(splt_u_overlap_time(state, current_split+1) / 100.0);
+
+          err = splt_u_put_output_format_filename(state);
+          if (err < 0) { *error = err; break; }
 
           if (!splt_t_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
           {
@@ -438,7 +447,8 @@ void splt_s_time_split(splt_state *state, int *error)
             final_fname = splt_u_get_fname_with_path_and_extension(state,&err);
             if (err < 0) { *error = err; break; }
 
-            splt_p_split(state, final_fname, begin, end, error, SPLT_TRUE);
+            splt_p_split(state, final_fname, begin, overlapped_end,
+                error, save_end_point);
 
             //if no error for the split, put the split file
             if (*error >= 0)
@@ -446,30 +456,36 @@ void splt_s_time_split(splt_state *state, int *error)
               err = splt_t_put_split_file(state, final_fname);
               if (err < 0) { *error = err; break; }
             }
+          }
 
-            //set new splitpoints
-            begin = end;
-            end += splt_t_get_float_option(state,SPLT_OPT_SPLIT_TIME);
-            tracks++;
+          //set new splitpoints
+          begin = end;
+          end += splt_t_get_float_option(state,SPLT_OPT_SPLIT_TIME);
+          tracks++;
 
-            //get out if error
-            if ((*error == SPLT_MIGHT_BE_VBR) ||
-                (*error==SPLT_OK_SPLIT_EOF) ||
-                (*error < 0))
-            {
-              tracks = 0;
-            }
-            if (*error==SPLT_ERROR_BEGIN_OUT_OF_FILE)
-            {
-              j--;
-            }
+          //get out if error
+          if ((*error == SPLT_MIGHT_BE_VBR) ||
+              (*error == SPLT_OK_SPLIT_EOF) ||
+              (*error < 0))
+          {
+            tracks = 0;
+          }
 
-            if (final_fname)
-            {
-              //free memory
-              free(final_fname);
-              final_fname = NULL;
-            }
+          if (*error==SPLT_ERROR_BEGIN_OUT_OF_FILE)
+          {
+            j--;
+          }
+
+          if (final_fname)
+          {
+            //free memory
+            free(final_fname);
+            final_fname = NULL;
+          }
+
+          if (last_file)
+          {
+            break;
           }
         }
         else
@@ -644,7 +660,13 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
     splt_t_put_message_to_client(state,client_infos);
     if (found > 0)
     {
-      snprintf(client_infos,512," (%d tracks)\n",found+1);
+      int selected_tracks = found + 1;
+      int param_number_of_tracks = splt_t_get_int_option(state, SPLT_OPT_PARAM_NUMBER_TRACKS);
+      if (param_number_of_tracks > 0)
+      {
+        selected_tracks = param_number_of_tracks;
+      }
+      snprintf(client_infos,512," (Selected %d tracks)\n", selected_tracks);
       splt_t_put_message_to_client(state,client_infos);
     }
     else
@@ -817,11 +839,10 @@ void splt_s_silence_split(splt_state *state, int *error)
 
       //set the default silence output
       int output_filenames = splt_t_get_int_option(state,SPLT_OPT_OUTPUT_FILENAMES);
-      int err = SPLT_OK;
       if (output_filenames == SPLT_OUTPUT_DEFAULT)
       {
-        splt_t_set_oformat(state, SPLT_DEFAULT_SILENCE_OUTPUT, &err);
-        if (err < 0) { *error = err; return; }
+        splt_t_set_oformat(state, SPLT_DEFAULT_SILENCE_OUTPUT, error, SPLT_TRUE);
+        if (*error < 0) { return; }
       }
 
       splt_s_multiple_split(state, error);
