@@ -686,8 +686,15 @@ void splt_t_set_oformat_digits(splt_state *state)
 }
 
 //puts the output format
-void splt_t_set_oformat(splt_state *state, const char *format_string, int *error)
+void splt_t_set_oformat(splt_state *state, const char *format_string,
+    int *error, int ignore_incorrect_format_warning)
 {
+  if (format_string == NULL)
+  {
+    *error = SPLT_OUTPUT_FORMAT_AMBIGUOUS;
+    return;
+  }
+
   int j = 0;
 
   //we clean out the output
@@ -704,7 +711,11 @@ void splt_t_set_oformat(splt_state *state, const char *format_string, int *error
   char *new_str = strdup(format_string);
   if (new_str)
   {
-    *error = splt_u_parse_outformat(new_str,state);
+    err = splt_u_parse_outformat(new_str, state);
+    if (! ignore_incorrect_format_warning)
+    {
+      *error = err;
+    }
     free(new_str);
     new_str = NULL;
   }
@@ -719,8 +730,6 @@ void splt_t_set_oformat(splt_state *state, const char *format_string, int *error
   {
     splt_t_set_oformat_digits(state); 
   }
-
-  splt_t_set_int_option(state, SPLT_OPT_OUTPUT_FILENAMES, SPLT_OUTPUT_FORMAT);
 }
 
 //returns the output format string
@@ -1002,12 +1011,23 @@ int splt_t_get_splitpoint_type(splt_state *state, int index, int *error)
 
 //if we auto increment the track number, we must replace the tracknumber in 
 //'all remaining tags like X'
-void splt_t_set_auto_increment_tracknumber_tag(splt_state *state, int old_current_split, int current_split)
+void splt_t_auto_increment_tracknumber_tag(splt_state *state)
 {
-  int remaining_tags_like_x = splt_t_get_int_option(state,SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X); 
+  //get the old current split and the current split
+  int current_split = splt_t_get_current_split_file_number(state) - 1;
+  int old_current_split = current_split;
 
+  //if we set all the tags like the x one
+  int remaining_tags_like_x = splt_t_get_int_option(state, SPLT_OPT_ALL_REMAINING_TAGS_LIKE_X); 
+
+  //auto increment track tag number if necessary
   if (remaining_tags_like_x != -1)
   {
+    if (current_split >= state->split.real_tagsnumber)
+    {
+      current_split = remaining_tags_like_x;
+    }
+
     if (splt_t_get_int_option(state, SPLT_OPT_AUTO_INCREMENT_TRACKNUMBER_TAGS) > 0)
     {
       if (current_split == remaining_tags_like_x)
@@ -1155,7 +1175,7 @@ int splt_t_append_only_non_null_previous_tags(splt_state *state,
     }
     if (error != SPLT_OK)
       return error;
-    if (track != -INT_MAX)
+    if (track != -1)
     {
       error = splt_t_set_tags_int_field(state,
           old_tagsnumber, SPLT_TAGS_TRACK, track);
@@ -2014,8 +2034,8 @@ static void splt_t_state_put_default_options(splt_state *state, int *error)
   state->wrap->wrap_files_num = 0;
   //output format
   state->oformat.format_string = NULL;
-  int err = splt_t_new_oformat(state,SPLT_DEFAULT_OUTPUT);
-  if (err < 0) { *error = err; return; }
+  splt_t_set_oformat(state, SPLT_DEFAULT_CDDB_CUE_OUTPUT, error, SPLT_TRUE);
+  if (*error < 0) { return; }
   //client connection
   state->split.put_message = NULL;
   state->split.file_split = NULL;
@@ -2041,11 +2061,13 @@ static void splt_t_state_put_default_options(splt_state *state, int *error)
   //options
   state->options.split_mode = SPLT_OPTION_NORMAL_MODE;
   state->options.tags = SPLT_CURRENT_TAGS;
+  state->options.xing = SPLT_TRUE;
   state->options.output_filenames = SPLT_OUTPUT_DEFAULT;
   state->options.quiet_mode = SPLT_FALSE;
   state->options.pretend_to_split = SPLT_FALSE;
   state->options.option_frame_mode = SPLT_TRUE;
   state->options.split_time = 6000;
+  state->options.overlap_time = 0;
   state->options.option_auto_adjust = SPLT_FALSE;
   state->options.option_input_not_seekable = SPLT_FALSE;
   state->options.create_dirs_from_filenames = SPLT_FALSE;
@@ -2199,6 +2221,9 @@ void splt_t_set_int_option(splt_state *state, int option_name, int value)
     case SPLT_OPT_TAGS:
       state->options.tags = value;
       break;
+    case SPLT_OPT_XING:
+      state->options.xing = value;
+      break;
     case SPLT_OPT_CREATE_DIRS_FROM_FILENAMES:
       state->options.create_dirs_from_filenames = value;
       break;
@@ -2238,6 +2263,19 @@ void splt_t_set_int_option(splt_state *state, int option_name, int value)
   }
 }
 
+void splt_t_set_long_option(splt_state *state, int option_name, long value)
+{
+  switch (option_name)
+  {
+    case SPLT_OPT_OVERLAP_TIME:
+      state->options.overlap_time = value;
+      break;
+    default:
+      splt_u_error(SPLT_IERROR_INT,__func__, option_name, NULL);
+      break;
+  }
+}
+
 //sets a float option
 void splt_t_set_float_option(splt_state *state, int option_name, float value)
 {
@@ -2281,6 +2319,9 @@ int splt_t_get_int_option(splt_state *state, int option_name)
     case SPLT_OPT_TAGS:
       return state->options.tags;
       break;
+    case SPLT_OPT_XING:
+      return state->options.xing;
+      break;
     case SPLT_OPT_CREATE_DIRS_FROM_FILENAMES:
       return state->options.create_dirs_from_filenames;
       break;
@@ -2322,6 +2363,21 @@ int splt_t_get_int_option(splt_state *state, int option_name)
   return -1;
 }
 
+long splt_t_get_long_option(splt_state *state, int option_name)
+{
+  switch (option_name)
+  {
+    case SPLT_OPT_OVERLAP_TIME:
+      return state->options.overlap_time;
+      break;
+    default:
+      splt_u_error(SPLT_IERROR_INT,__func__, option_name, NULL);
+      break;
+  }
+
+  return -1;
+}
+
 //returns a float option (see mp3splt_types.h for int options)
 float splt_t_get_float_option(splt_state *state, int option_name)
 {
@@ -2400,11 +2456,15 @@ void splt_t_freedb_free_search(splt_state *state)
 
 //sets a freedb result
 //if revision != -1, then not a revision
-//-album_name must not be NULL
 int splt_t_freedb_append_result(splt_state *state, const char *album_name, int revision)
 {
   int error = SPLT_OK;
 
+  if (album_name == NULL)
+  {
+    return error;
+  }
+
   //if we had not initialised the 
   //search_results variable, do it now
   if (state->fdb.search_results->number == 0)
@@ -2418,7 +2478,6 @@ int splt_t_freedb_append_result(splt_state *state, const char *album_name, int r
     {
       state->fdb.search_results->results[0].revisions = NULL;
       state->fdb.search_results->results[0].name = strdup(album_name);
-      //if strdup fails
       if (state->fdb.search_results->results[0].name == NULL)
       {
         error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
@@ -2452,7 +2511,6 @@ int splt_t_freedb_append_result(splt_state *state, const char *album_name, int r
       {
         state->fdb.search_results->results[state->fdb.search_results->number]
           .name = strdup(album_name);
-        //if strdup fails
         if (state->fdb.search_results->results[state->fdb.search_results->number]
             .name == NULL)
         {
@@ -2809,7 +2867,6 @@ void splt_t_serrors_free(splt_state *state)
 
 //appends a file from to the wrap files
 int splt_t_wrap_put_file(splt_state *state,
-    //how many files
     int wrapfiles, int index, const char *filename)
 {
   int error = SPLT_OK;
@@ -2829,14 +2886,21 @@ int splt_t_wrap_put_file(splt_state *state,
 
   if (error == SPLT_OK)
   {
-    //if strdup fails
-    if ((state->wrap->wrap_files[index] = strdup(filename)) == NULL)
+    if (filename == NULL)
     {
-      error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+      state->wrap->wrap_files[index] = NULL;
+      state->wrap->wrap_files_num++;
     }
     else
     {
-      state->wrap->wrap_files_num++;
+      if ((state->wrap->wrap_files[index] = strdup(filename)) == NULL)
+      {
+        error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+      }
+      else
+      {
+        state->wrap->wrap_files_num++;
+      }
     }
   }
 
