@@ -287,7 +287,7 @@ const char *splt_u_get_real_name(const char *filename)
 //state->fn[i]
 //error is the possible error
 //result must be freed
-static char *splt_u_get_mins_secs_filename(char *filename, splt_state *state,
+static char *splt_u_get_mins_secs_filename(const char *filename, splt_state *state,
     long split_begin, long split_end, int i, int *error)
 {
   int number_of_splits = 0;
@@ -400,13 +400,18 @@ static char *splt_u_get_mins_secs_filename(char *filename, splt_state *state,
 //error is the possible error
 void splt_u_set_complete_mins_secs_filename(splt_state *state, int *error)
 {
+  char *filename = splt_t_get_filename_to_split(state);
+  if (filename == NULL)
+  {
+    return;
+  }
+
   int get_error = SPLT_OK;
   int current_split = splt_t_get_current_split(state);
   long split_begin = splt_t_get_splitpoint_value(state, current_split, &get_error);
   if (get_error < 0) { *error = get_error; return; }
   long split_end = splt_t_get_splitpoint_value(state, current_split+1, &get_error);
   if (get_error < 0) { *error = get_error; return; }
-  char *filename = splt_t_get_filename_to_split(state);
 
   char *filename2 = strdup(filename);
   if (!filename2)
@@ -420,40 +425,16 @@ void splt_u_set_complete_mins_secs_filename(splt_state *state, int *error)
     char *fname = NULL;
 
     //get the filename without the path
-    char *filename3 = strdup(splt_u_get_real_name(filename2));
-    if (!filename3)
+    const char *ptr = splt_u_get_real_name(filename2);
+    if (ptr)
     {
-      if (filename2)
-      {
-        free(filename2);
-        filename2 = NULL;
-      }
-      *error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-    }
-    else
-    {
-      fname = splt_u_get_mins_secs_filename(filename3, state,
+      fname = splt_u_get_mins_secs_filename(ptr, state,
           split_begin, split_end, current_split, error);
 
       if (*error >= 0)
       {
-        //we cut the extension
-        char *fname2 = strdup(fname);
-        if (fname2)
-        {
-          fname2[strlen(fname2)-4]='\0';
-          //we put the filename in the state
-          splt_t_set_splitpoint_name(state, current_split, fname2);
-          if (fname2)
-          {
-            free(fname2);
-            fname2 = NULL;
-          }
-        }
-        else
-        {
-          *error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-        }
+        splt_u_cut_extension(fname);
+        splt_t_set_splitpoint_name(state, current_split, fname);
       }
 
       if (fname)
@@ -461,13 +442,6 @@ void splt_u_set_complete_mins_secs_filename(splt_state *state, int *error)
         free(fname);
         fname = NULL;
       }
-
-      //free some memory
-      if (filename3)
-      {
-        free(filename3);
-        filename3 = NULL;
-      }
     }
 
     //free some memory
@@ -660,7 +634,7 @@ void splt_u_order_splitpoints(splt_state *state, int len)
 //parse the word, returns a allocated string with the recognised word
 //-return must be freed
 static char *splt_u_parse_tag_word(const char *cur_pos,
-    const char *end_paranthesis, int *ambigous, int *error)
+    const char *end_paranthesis, int *ambiguous, int *error)
 {
   char *word = NULL;
   char *word_end = NULL;
@@ -675,7 +649,7 @@ static char *splt_u_parse_tag_word(const char *cur_pos,
       if ((strchr(word_end+1,']') && !strchr(word_end+1,'['))
           || (strchr(word_end+1,']') < strchr(word_end+1,'[')))
       {
-        *ambigous = SPLT_TRUE;
+        *ambiguous = SPLT_TRUE;
       }
     }
 
@@ -683,7 +657,7 @@ static char *splt_u_parse_tag_word(const char *cur_pos,
     {
       if (*(word_end+1) != '@')
       {
-        *ambigous = SPLT_TRUE;
+        *ambiguous = SPLT_TRUE;
       }
     }
   }
@@ -715,12 +689,12 @@ static char *splt_u_parse_tag_word(const char *cur_pos,
       }
       else
       {
-        *ambigous = SPLT_TRUE;
+        *ambiguous = SPLT_TRUE;
       }
     }
     else
     {
-      *ambigous = SPLT_TRUE;
+      *ambiguous = SPLT_TRUE;
     }
   }
 
@@ -730,7 +704,7 @@ static char *splt_u_parse_tag_word(const char *cur_pos,
 }
 
 //we put the custom tags
-//returns if ambigous or not
+//returns if ambiguous or not
 int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
 {
   if (tags != NULL)
@@ -741,12 +715,12 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
 
     cur_pos = tags;
 
-    int ambigous = SPLT_FALSE;
+    int ambiguous = SPLT_FALSE;
     const char *end_paranthesis = NULL;
     //we search for tags
     if (!strchr(cur_pos,'['))
     {
-      ambigous = SPLT_TRUE;
+      ambiguous = SPLT_TRUE;
     }
 
     //tags that we put to all the others : %[@t=tag1,@b=album1]
@@ -812,7 +786,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
       end_paranthesis = strchr(cur_pos,']');
       if (!end_paranthesis)
       {
-        ambigous = SPLT_TRUE;
+        ambiguous = SPLT_TRUE;
       }
       else
       {
@@ -820,7 +794,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
             (*(end_paranthesis+1) != '%') &&
             (*(end_paranthesis+1) != '\0'))
         {
-          ambigous = SPLT_TRUE;
+          ambiguous = SPLT_TRUE;
         }
       }
 
@@ -848,14 +822,14 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               //if we have twice @o
               if (original_tags)
               {
-                ambigous = SPLT_TRUE;
+                ambiguous = SPLT_TRUE;
               }
               //if we have other thing than @o, or @o]
-              //then ambigous
+              //then ambiguous
               if ((*(cur_pos+1) != ',') &&
                   (*(cur_pos+1) != ']'))
               {
-                ambigous = SPLT_TRUE;
+                ambiguous = SPLT_TRUE;
               }
 
               //if we don't have STDIN
@@ -945,23 +919,19 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
                   goto end_while;
                 }
               }
-              else
-              {
-                ambigous = SPLT_TRUE;
-              }
 
               //if we have a @a,@p,.. before @n
-              //then ambigous
+              //then ambiguous
               if ((artist != NULL) || (performer != NULL) ||
                   (album != NULL) || (title != NULL) ||
                   (comment != NULL) || (year != NULL) ||
                   (tracknumber != NULL))
               {
-                ambigous = SPLT_TRUE;
+                ambiguous = SPLT_TRUE;
               }
               break;
             case 'a':
-              artist = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambigous, error);
+              artist = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambiguous, error);
               if (*error < 0) { get_out_from_while = SPLT_TRUE; goto end_while; }
               if (artist != NULL)
               {
@@ -980,7 +950,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               }
               break;
             case 'p':
-              performer = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambigous, error);
+              performer = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambiguous, error);
               if (*error < 0) { get_out_from_while = SPLT_TRUE; goto end_while; }
               if (performer != NULL)
               {
@@ -999,7 +969,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               }
               break;
             case 'b':
-              album = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambigous,error);
+              album = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambiguous,error);
               if (*error < 0) { get_out_from_while = SPLT_TRUE; goto end_while; }
               if (album != NULL)
               {
@@ -1018,7 +988,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               }
               break;
             case 't':
-              title = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambigous,error);
+              title = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambiguous,error);
               if (*error < 0) { get_out_from_while = SPLT_TRUE; goto end_while; }
               if (title != NULL)
               {
@@ -1038,7 +1008,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               }
               break;
             case 'c':
-              comment = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambigous,error);
+              comment = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambiguous,error);
               if (*error < 0) { get_out_from_while = SPLT_TRUE; goto end_while; }
               if (comment != NULL)
               {
@@ -1058,7 +1028,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               }
               break;
             case 'y':
-              year = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambigous,error);
+              year = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambiguous,error);
               if (*error < 0) { get_out_from_while = SPLT_TRUE; goto end_while; }
               if (year != NULL)
               {
@@ -1078,7 +1048,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               }
               break;
             case 'n':
-              tracknumber = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambigous,error);
+              tracknumber = splt_u_parse_tag_word(cur_pos,end_paranthesis,&ambiguous,error);
               if (*error < 0) { get_out_from_while = SPLT_TRUE; goto end_while; }
               if (tracknumber != NULL)
               {
@@ -1095,7 +1065,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               }
               break;
             case 'N':
-              tracknumber = splt_u_parse_tag_word(cur_pos,end_paranthesis, &ambigous,error);
+              tracknumber = splt_u_parse_tag_word(cur_pos,end_paranthesis, &ambiguous,error);
               if (*error < 0) { get_out_from_while = SPLT_TRUE; goto end_while; }
               splt_t_set_int_option(state,SPLT_OPT_AUTO_INCREMENT_TRACKNUMBER_TAGS, SPLT_TRUE);
               if (auto_increment_tracknumber)
@@ -1109,7 +1079,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
               }
               break;
             default:
-              ambigous = SPLT_TRUE;
+              ambiguous = SPLT_TRUE;
               break;
           }
         }
@@ -1131,7 +1101,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
           if (!isdigit(tracknumber[i]))
           {
             is_number = SPLT_FALSE;
-            ambigous = SPLT_TRUE;
+            ambiguous = SPLT_TRUE;
           }
         }
         if (is_number)
@@ -1162,7 +1132,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
           || (s_year > 1) || (s_comment > 1)
           || (s_tracknumber > 1))
       {
-        ambigous = SPLT_TRUE;
+        ambiguous = SPLT_TRUE;
       }
 
       //if we don't have already set the original tags,
@@ -1196,7 +1166,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
       }
 
       //if we have all tags, set them
-      if (we_had_all_tags)
+      if (we_had_all_tags && !original_tags)
       {
         int index = state->split.real_tagsnumber - 1;
         if (!title)
@@ -1227,7 +1197,7 @@ int splt_u_put_tags_from_string(splt_state *state, const char *tags, int *error)
         {
           splt_t_set_tags_int_field(state, index, SPLT_TAGS_TRACK, all_tracknumber);
         }
-        if (genre != 12)
+        if (genre == 12)
         {
           splt_t_set_tags_uchar_field(state, index, SPLT_TAGS_GENRE, all_genre);
         }
@@ -1267,7 +1237,7 @@ end_while:
     if (all_year) { free(all_year); all_year = NULL; }
     if (all_comment) { free(all_comment); all_comment = NULL; }
 
-    return ambigous;
+    return ambiguous;
   }
 
   return SPLT_FALSE;
@@ -1276,8 +1246,6 @@ end_while:
 /*******************************/
 /* utils for the output format */
 
-//parse the output format to see if correct
-//use strdup on 's' when calling this function
 int splt_u_parse_outformat(char *s, splt_state *state)
 {
   char *ptrs = NULL, *ptre = NULL;
@@ -1322,15 +1290,18 @@ int splt_u_parse_outformat(char *s, splt_state *state)
     ptre = s;
   }
 
-  //if stdout, NOT ambigous
+  //if stdout, NOT ambiguous
   if (splt_t_is_stdout(state))
   {
     return SPLT_OUTPUT_FORMAT_OK;
   }
 
+  char err[2] = { '\0' };
+
   if (ptre == NULL)
   {
-    return SPLT_OUTPUT_FORMAT_AMBIGUOUS;
+    splt_t_set_error_data(state, err);
+    return SPLT_OUTPUT_FORMAT_ERROR;
   }
   ptrs = ptre;
 
@@ -1346,20 +1317,25 @@ int splt_u_parse_outformat(char *s, splt_state *state)
 
     switch (cf)
     {
+      case 's':
+      case 'S':
+      case 'm':
+      case 'M':
+      case 'h':
+      case 'H':
       case 'a':
-        break;
       case 'b':
-        break;
-      case 't':
-        break;
-      case 'n':
-        amb = SPLT_OUTPUT_FORMAT_OK;
-        break;
       case 'f':
-        break;
       case 'p':
         break;
+      case 't':
+      case 'n':
+      case 'N':
+        amb = SPLT_OUTPUT_FORMAT_OK;
+        break;
       default:
+        err[0] = cf;
+        splt_t_set_error_data(state, err);
         return SPLT_OUTPUT_FORMAT_ERROR;
     }
 
@@ -1382,11 +1358,32 @@ int splt_u_parse_outformat(char *s, splt_state *state)
   return amb;
 }
 
+static char *splt_u_get_format_ptr_and_set_number_of_digits(splt_state *state, int i, char *temp, int *number_of_digits)
+{
+  *number_of_digits = state->oformat.output_format_digits;
+  int format_length = strlen(state->oformat.format[i]);
+  char *format = state->oformat.format[i];
+  if ((format_length > 2) && isdigit(state->oformat.format[i][2]))
+  {
+    temp[2] = state->oformat.format[i][2];
+    *number_of_digits = (int) state->oformat.format[i][2];
+    format = state->oformat.format[i] + 1;
+  }
+
+  return format;
+}
+
 //writes the current filename according to the output_filename
 int splt_u_put_output_format_filename(splt_state *state)
 {
   int error = SPLT_OK;
 
+  int output_filenames = splt_t_get_int_option(state, SPLT_OPT_OUTPUT_FILENAMES);
+  if (output_filenames == SPLT_OUTPUT_CUSTOM)
+  {
+    return error;
+  }
+
   char *temp = NULL;
   char *fm = NULL;
   int i = 0;
@@ -1402,6 +1399,25 @@ int splt_u_put_output_format_filename(splt_state *state)
   int old_current_split = splt_t_get_current_split_file_number(state) - 1;
   int current_split = old_current_split;
 
+  long mins = -1;
+  long secs = -1;
+  long hundr = -1;
+  long point_value = splt_t_get_splitpoint_value(state, old_current_split, &error);
+  splt_u_get_mins_secs_hundr(point_value, &mins, &secs, &hundr);
+  long next_mins = -1;
+  long next_secs = -1;
+  long next_hundr = -1;
+  if (splt_t_splitpoint_exists(state, old_current_split + 1))
+  {
+    point_value = splt_t_get_splitpoint_value(state, old_current_split +1, &error);
+    long total_time = splt_t_get_total_time(state);
+    if (point_value > total_time)
+    {
+      point_value = total_time;
+    }
+    splt_u_get_mins_secs_hundr(point_value, &next_mins, &next_secs, &next_hundr);
+  }
+
   int fm_length = 0;
 
   //if we get the tags from the first file
@@ -1415,6 +1431,8 @@ int splt_u_put_output_format_filename(splt_state *state)
 
   splt_u_print_debug("The output format is ",0,state->oformat.format_string);
 
+  long mMsShH_value = -1;
+
   for (i = 0; i < SPLT_OUTNUM; i++)
   {
     if (strlen(state->oformat.format[i]) == 0)
@@ -1441,8 +1459,72 @@ int splt_u_put_output_format_filename(splt_state *state)
 
       temp[0] = '%';
       temp[1] = 's';
-      switch (state->oformat.format[i][1])
+      char char_variable = state->oformat.format[i][1];
+      switch (char_variable)
       {
+        case 's':
+          mMsShH_value = secs;
+          goto put_value;
+        case 'S':
+          mMsShH_value = next_secs;
+          goto put_value;
+        case 'm':
+          mMsShH_value = mins;
+          goto put_value;
+        case 'M':
+          mMsShH_value = next_mins;
+          goto put_value;
+        case 'h':
+          mMsShH_value = hundr;
+          goto put_value;
+        case 'H':
+          mMsShH_value = next_hundr;
+put_value:
+          temp[1] = '0';
+          temp[2] = '2';
+          temp[3] = 'l';
+          temp[4] = 'd';
+
+          if (mMsShH_value != -1)
+          {
+            char *format = NULL;
+            int number_of_digits = state->oformat.output_format_digits;
+            int offset = 5;
+
+            //don't print out @h or @H if 0 for default output
+            if ((strcmp(state->oformat.format_string, SPLT_DEFAULT_OUTPUT) == 0) &&
+                (mMsShH_value == 0) &&
+                (char_variable == 'h' || char_variable == 'H'))
+            {
+              if (char_variable == 'h')
+              {
+                format = state->oformat.format[i]+2;
+                offset = 0;
+              }
+              else
+              {
+                output_filename[strlen(output_filename)-1] = '\0';
+                break;
+              }
+            }
+            else
+            {
+              format = splt_u_get_format_ptr_and_set_number_of_digits(state, i,
+                  temp, &number_of_digits);
+            }
+
+            snprintf(temp + offset, temp_len, format + 2);
+
+            fm_length = strlen(temp) + 1 + number_of_digits;
+            if ((fm = malloc(fm_length * sizeof(char))) == NULL)
+            {
+              error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+              goto end;
+            }
+
+            snprintf(fm, fm_length, temp, mMsShH_value);
+          }
+          break;
         case 'a':
           if (splt_t_tags_exists(state,current_split))
           {
@@ -1621,36 +1703,26 @@ int splt_u_put_output_format_filename(splt_state *state)
           }
           break;
         case 'n':
+        case 'N':
           temp[1] = '0';
           temp[2] = state->oformat.output_format_digits;
           temp[3] = 'd';
 
           int number_of_digits = state->oformat.output_format_digits;
+          char *format = splt_u_get_format_ptr_and_set_number_of_digits(state, i, temp,
+              &number_of_digits);
 
-          int format_length = strlen(state->oformat.format[i]);
-          char *format_dup = strdup(state->oformat.format[i]);
-          if ((format_length > 2) &&
-              isdigit(state->oformat.format[i][2]))
-          {
-            temp[2] = state->oformat.format[i][2];
-            number_of_digits = (int) state->oformat.format[i][2];
-            int k = 0;
-            for (k = 2;k < format_length;k++)
-            {
-              format_dup[k] = format_dup[k+1];
-            }
-          }
-
-          //we set the track number
+         //we set the track number
           int tracknumber = old_current_split + 1;
 
           //if not time split, or normal split, or silence split or error,
           //we put the track number from the tags
           int split_mode = splt_t_get_int_option(state,SPLT_OPT_SPLIT_MODE);
-          if ((split_mode != SPLT_OPTION_TIME_MODE) &&
-              (split_mode != SPLT_OPTION_NORMAL_MODE) &&
-              (split_mode != SPLT_OPTION_SILENCE_MODE) &&
-              (split_mode != SPLT_OPTION_ERROR_MODE))
+          if ((state->oformat.format[i][1] == 'N') ||
+              ((split_mode != SPLT_OPTION_TIME_MODE) &&
+               (split_mode != SPLT_OPTION_NORMAL_MODE) &&
+               (split_mode != SPLT_OPTION_SILENCE_MODE) &&
+               (split_mode != SPLT_OPTION_ERROR_MODE)))
           {
             if (splt_t_tags_exists(state,current_split))
             {
@@ -1662,12 +1734,8 @@ int splt_u_put_output_format_filename(splt_state *state)
               }
             }
           }
-          snprintf(temp+4, temp_len, format_dup+2);
-          if (format_dup)
-          {
-            free(format_dup);
-            format_dup = NULL;
-          }
+
+          snprintf(temp+4, temp_len, format+2);
 
           fm_length = strlen(temp) + 1 + number_of_digits;
           if ((fm = malloc(fm_length * sizeof(char))) == NULL)
@@ -2114,6 +2182,9 @@ char *splt_u_strerror(splt_state *state, int error_code)
             " error: splitpoints are equal (%s)",
             state->err.error_data);
         break;
+      case SPLT_ERROR_TIME_SPLIT_VALUE_INVALID :
+        snprintf(error_msg,max_error_size, " error: invalid time split value");
+        break;
       case SPLT_ERROR_SPLITPOINTS_NOT_IN_ORDER :
         snprintf(error_msg,max_error_size,
             " error: the splitpoints are not in order (%s)",
@@ -2198,11 +2269,19 @@ char *splt_u_strerror(splt_state *state, int error_code)
       case SPLT_OUTPUT_FORMAT_OK:
         break;
       case SPLT_OUTPUT_FORMAT_AMBIGUOUS:
-        snprintf(error_msg,max_error_size, " warning: output format ambigous (@t or @n missing)");
+        snprintf(error_msg,max_error_size, " warning: output format ambiguous (@t or @n missing)");
         break;
         //
       case SPLT_OUTPUT_FORMAT_ERROR:
-        snprintf(error_msg,max_error_size, " warning: output format error");
+        if (state->err.error_data == NULL || strlen(state->err.error_data) == 0)
+        {
+          snprintf(error_msg,max_error_size, " error: invalid output format");
+        }
+        else
+        {
+          snprintf(error_msg,max_error_size, " error: illegal variable '@%s' in output format",
+              state->err.error_data);
+        }
         break;
         //
       case SPLT_ERROR_INEXISTENT_SPLITPOINT:
@@ -2281,6 +2360,26 @@ double splt_u_get_double_pos(long split)
   return pos;
 }
 
+void splt_u_get_mins_secs_hundr(long split_hundr, long *mins, long *secs, long *hundr)
+{
+  long h = split_hundr % 100;
+  long split_hundr_without_h = split_hundr / 100;
+  long m = split_hundr_without_h / 60;
+  long s = split_hundr_without_h % 60;
+  if (mins)
+  {
+    *mins = m;
+  }
+  if (secs)
+  {
+    *secs = s;
+  }
+  if (hundr)
+  {
+    *hundr = h;
+  }
+}
+
 int splt_u_parse_ssplit_file(splt_state *state, FILE *log_file, int *error)
 {
   char line[512] = { '\0' };
@@ -2363,30 +2462,33 @@ int splt_u_create_directories(splt_state *state, const char *dir)
     }
   }
 
-  //we have created all the directories except the last one
-  char *last_dir = strdup(dir);
-  if (!last_dir)
+  if (dir)
   {
-    result = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
-    goto end;
-  }
-
-  if (! splt_u_check_if_directory(last_dir))
-  {
-    splt_u_print_debug("final directory ...",0, last_dir);
-
-    if ((splt_u_mkdir(last_dir)) == -1)
+    //we have created all the directories except the last one
+    char *last_dir = strdup(dir);
+    if (!last_dir)
     {
-      splt_t_set_strerror_msg(state);
-      splt_t_set_error_data(state,last_dir);
-      result = SPLT_ERROR_CANNOT_CREATE_DIRECTORY;
+      result = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+      goto end;
+    }
+
+    if (! splt_u_check_if_directory(last_dir))
+    {
+      splt_u_print_debug("final directory ...",0, last_dir);
+
+      if ((splt_u_mkdir(last_dir)) == -1)
+      {
+        splt_t_set_strerror_msg(state);
+        splt_t_set_error_data(state,last_dir);
+        result = SPLT_ERROR_CANNOT_CREATE_DIRECTORY;
+      }
+    }
+
+    if (last_dir)
+    {
+      free(last_dir);
+      last_dir = NULL;
     }
-  }
-  
-  if (last_dir)
-  {
-    free(last_dir);
-    last_dir = NULL;
   }
 
 end:
@@ -2619,3 +2721,61 @@ int splt_u_stat(const char *path, mode_t *st_mode, off_t *st_size)
   }
 }
 
+char *splt_u_safe_strdup(char *input, int *error)
+{
+  if (input == NULL)
+  {
+    return NULL;
+  }
+  else
+  {
+    char *dup_input = strdup(input);
+    if (dup_input != NULL)
+    {
+      return dup_input;
+    }
+    else
+    {
+      *error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+      return NULL;
+    }
+  }
+}
+
+void splt_u_print_overlap_time(splt_state *state)
+{
+  long overlap_time = splt_t_get_long_option(state, SPLT_OPT_OVERLAP_TIME);
+  if (overlap_time > 0)
+  {
+    char message[1024] = { '\0' };
+    long mins = -1;
+    long secs = -1;
+    long hundr = -1;
+    splt_u_get_mins_secs_hundr(overlap_time, &mins, &secs, &hundr);
+    snprintf(message, 1024,
+        " info: overlapping split files with %ld.%ld.%ld\n", mins, secs, hundr);
+    splt_t_put_message_to_client(state, message);
+  }
+}
+
+long splt_u_overlap_time(splt_state *state, int splitpoint_index)
+{
+  int error = SPLT_OK;
+  long split_value = splt_t_get_splitpoint_value(state, splitpoint_index, &error);
+  long overlap_time = splt_t_get_long_option(state, SPLT_OPT_OVERLAP_TIME);
+  if ((overlap_time > 0) && (split_value != LONG_MAX))
+  {
+    long total_time = splt_t_get_total_time(state);
+    long overlapped_split_value = split_value + overlap_time;
+    if (overlapped_split_value > total_time)
+    {
+      overlapped_split_value = total_time;
+    }
+    splt_t_set_splitpoint_value(state, splitpoint_index, overlapped_split_value);
+
+    return overlapped_split_value;
+  }
+
+  return split_value;
+}
+
